@@ -4,11 +4,10 @@ Implements a client class to query the
 """
 
 import json
-try:
+try:  # pragma: no cover - python 2
     from urllib import urlencode
     from urllib2 import urlopen
-except ImportError:
-    #python 3
+except ImportError:  # pragma: no cover - python 3
     from urllib.parse import urlencode
     from urllib.request import urlopen
 from deezer.resources import Album, Artist, Comment, Genre
@@ -78,16 +77,16 @@ class Client(object):
         object_class = self.objects_types.get(result['type'], Resource)
         return object_class(self, result)
 
-    def make_str(self, value):
+    @staticmethod
+    def make_str(value):
         """
         Convert value to str in python2 and python3 compatible way
 
         :returns: str instance
         """
-        try:
+        try:  # pragma: no cover - python 3
             value = str(value)
-        except UnicodeEncodeError:
-            #python2
+        except UnicodeEncodeError:  # pragma: no cover - python 2
             value = value.encode('utf-8')
         return value
 
@@ -102,7 +101,7 @@ class Client(object):
         """Build the url with the appended request if provided."""
         if request.startswith('/'):
             request = request[1:]
-        return "%s://%s/%s" % (self.scheme, self.host, request)
+        return "{0}://{1}/{2}".format(self.scheme, self.host, request)
 
     def object_url(self, object_t, object_id=None, relation=None, **kwargs):
         """
@@ -112,7 +111,7 @@ class Client(object):
         :raises TypeError: if the object type is invalid
         """
         if object_t not in self.objects_types:
-            raise TypeError("%s is not a valid type" % object_t)
+            raise TypeError("{0} is not a valid type".format(object_t))
         request_items = (object_t, object_id, relation)
         request_items = (item for item in request_items if item is not None)
         request_items = (str(item) for item in request_items)
@@ -122,7 +121,7 @@ class Client(object):
             for key, value in kwargs.items():
                 if not isinstance(value, str):
                     kwargs[key] = self.make_str(value)
-            result = '%s?%s' % (base_url, urlencode(kwargs))
+            result = '{0}?{1}'.format(base_url, urlencode(kwargs))
         else:
             result = base_url
         return result
